import com.apple.yellow.foundation.*;
import com.apple.yellow.webobjects.*;
import java.util.*;

/*
        Copyright (c) 1999, Apple Computer, Inc.
        All rights reserved.

        You may freely copy, distribute and reuse the code in this example.
        Apple disclaims any warranty of any kind, expressed or implied,
        as to its fitness for any particular use.
*/

// an example of a WOComponent that monitors and gives user feedback 
// to a long running process. associated web page Model/View displays dynamic 
// width table cells as a simple illustration of "pushing" values to the client.

public class ExampleLRP0 extends LongResponsePage {
    private boolean _debug = false;
    private PrimeNumberComputer pnc;
    protected int start;
    protected int stop;
    protected int count;
    protected int barWidth = 0;
    protected int tableWidth = 300;
    protected int remainingWidth = tableWidth-barWidth;
    protected String barWidthPercentageString = "0";
    protected String barWidthRemainingString = "0";

    public ExampleLRP0() {
        super();
        setRefreshInterval(1);
    }

    // this is the "run" method for an implementation of a long running page.
    // in this case the performer is sent knowledge of this component
    // so the component can receive updated values.
    // registering a Java event listener would be similar.
    public void performAction() {
        pnc = new PrimeNumberComputer();
        pnc.calculatePrimes(start,stop);
    }

    private void getLastStatus() {
        Vector statusVector = pnc.statusVector();
        int howmanyprimes = ((Vector)(statusVector.lastElement())).size();
        if (_debug) System.out.println("\nIn ExampleLRP0 refreshPage # of primes: "+howmanyprimes);
        if (statusVector != null) {
            count = ((Integer)(statusVector.firstElement())).intValue(); // how many tested
            if (howmanyprimes == 0) barWidth = 0;
            else barWidth = (int)((double)count/(double)stop*tableWidth);
            barWidthPercentageString = (new Integer((int)((double)barWidth/(double)tableWidth*100.0))).toString()+"%";
            remainingWidth = tableWidth-barWidth;
            barWidthRemainingString = (new Integer((int)((double)remainingWidth/(double)tableWidth*100.0))).toString()+"%";
        }
    }

    // this is the Controller for this example
    // refreshPage is called in PrimeNumberComputer
    public WOComponent refreshPage() {
        getLastStatus();
        return null;
    }

    public WOComponent pageForResult() {
        ResultsPage resultPage = (ResultsPage)this.pageWithName("ResultsPage");
        resultPage.setStart(start);
        resultPage.setStop(stop);
        Vector statusVector = pnc.statusVector();
        if (statusVector != null) resultPage.setResults(((Vector)statusVector.elementAt(1)).size());
        return resultPage;
    }

    public WOComponent cancelPage() {
        pnc.cancel();
        CancelPage cancelPage = (CancelPage)this.pageWithName("CancelPage");
        cancelPage.setStart(start);
        cancelPage.setStop(stop);
        Vector statusVector = pnc.statusVector();
        if (statusVector != null) cancelPage.setResults(((Vector)statusVector.elementAt(1)).size());
        return cancelPage;
    }

    // Accessors

    public void setStart(int start) {
        this.start = start;
    }

    public void setStop(int stop) {
        if (_debug) System.out.println("\n***** In ExampleLRP0 stop = "+stop);
        this.stop = stop;
    }
}
