import com.apple.yellow.foundation.*;
import com.apple.yellow.webobjects.*;
import java.util.*;

/*
        Copyright (c) 1999, Apple Computer, Inc.
        All rights reserved.

        You may freely copy, distribute and reuse the code in this example.
        Apple disclaims any warranty of any kind, expressed or implied,
        as to its fitness for any particular use.
*/

// an example of a WOComponent that monitors and gives user feedback
// to a long running process. associated web page Model/View displays dynamic
// width table cells as a simple illustration of "pushing" values to the client.

public class ExampleLRP1 extends LongResponsePage {
    private PrimeNumberComputer pnc;
    private int displayCount = 10;
    private boolean _debug = true;
    protected int start;
    protected int stop;
    protected int count;
    protected int howmanyprimes = 0;
    protected String listItem = "";
    protected NSMutableArray array = new NSMutableArray();
    
    public ExampleLRP1() {
        super();
        setRefreshInterval(0);
    }

    // this is the "run" method for an implementation of a long running page.
    // in this case the performer is sent knowledge of this component
    // so the component can receive updated values.
    // registering a Java event listener would be similar.
    public void performAction() {
        pnc = new PrimeNumberComputer();
        pnc.calculatePrimes(start,stop);
    }

    private void getLastStatus() {
        Vector statusVector = pnc.statusVector();
        if (statusVector == null) System.out.println("In ExampleLRP1 statusVector is null");
        else {
            count = ((Integer)(statusVector.firstElement())).intValue(); // how many tested
            int howmanyprimes = ((Vector)(statusVector.lastElement())).size();
            if (array.count() > 0) array.removeAllObjects();
            Vector tmp = (Vector)statusVector.lastElement();
            for (int i=0;i<10;i++) {
                String s = ((Integer)tmp.elementAt(howmanyprimes-displayCount+i)).toString();
                array.insertObjectAtIndex(s,i);
            }
        }
    }

    // this is the Controller for this example
    // refreshPage is called in PrimeNumberComputer
    // since _refreshInterval is zero in this version meta refresh does not occur
    public WOComponent refreshPage() {
        if (_debug) System.out.println("\nIn ExampleLRP1 refreshPage");
        getLastStatus();
        return null;
    }

    public WOComponent pageForResult() {
        ResultsPage resultPage = (ResultsPage)this.pageWithName("ResultsPage");
        resultPage.setStart(start);
        resultPage.setStop(stop);
        Vector statusVector = pnc.statusVector();
        if (statusVector != null) resultPage.setResults(((Vector)statusVector.elementAt(1)).size());
        return resultPage;
    }

    public WOComponent cancelPage() {
        System.out.println("\nIn ExampleLRP1 cancelPage()");
        pnc.cancel();
        setCancelled(true); // method in LongResponsePage.java
        CancelPage cancelPage = (CancelPage)this.pageWithName("CancelPage");
        cancelPage.setStart(start);
        cancelPage.setStop(stop);
        Vector statusVector = pnc.statusVector();
        if (statusVector != null) cancelPage.setResults(((Vector)statusVector.elementAt(1)).size());
        return cancelPage;
    }
    
    // Accessors

    public void setStart(int start) {
        this.start = start;
    }

    public void setStop(int stop) {
        System.out.println("\n***** In ExampleLRP1 stop = "+stop);
        this.stop = stop;
    }
}
